****************
Acknowledgements
****************

Thank you to JetBrains for the free use of `PyCharm <https://www.jetbrains.com/pycharm/>`_.

Stingray participated in the `Google Summer of Code <https://summerofcode.withgoogle.com>`_ in 2018 and 2020 under `Open Astronomy <http://openastronomy.org>`_, in 2017 under the `Python Software Foundation <https://www.python.org/psf/>`_, and in 2016 under `Timelab <http://timelabtechnologies.com>`_.
